@@ -1,5 +1,6 @@
 from types import FunctionType
 
+from algebra.util import identical
 from lab import B
 from matrix import AbstractMatrix, Zero, Diagonal
 from plum import convert, Union
@@ -95,8 +96,10 @@ class Normal(RandomVector):
         if self._mean is None:
             self._mean = self._construct_mean()
         if self._mean_is_zero is None:
-            self._mean_is_zero = self._mean is 0 or isinstance(self._mean, Zero)
-        if self._mean is 0 and construct_zeros:
+            identically_zero = identical(self._mean, 0)
+            zero_matrix = isinstance(self._mean, Zero)
+            self._mean_is_zero = identically_zero or zero_matrix
+        if identical(self._mean, 0) and construct_zeros:
             self._mean = B.zeros(self.dtype, self.dim, 1)
 
     def _resolve_var(self):
@@ -298,7 +301,7 @@ class Normal(RandomVector):
             scalar: KL divergence.
         """
         return (
-            B.iqf_diag(other.var, other.mean - self.mean)[0]
+            B.iqf_diag(other.var, other.mean - self.mean)[..., 0]
             + B.ratio(self.var, other.var)
             + B.logdet(other.var)
             - B.logdet(self.var)
