@@ -11,7 +11,6 @@ from mlkernels import (
     EQ,
     Delta,
     Exp,
-    TensorProductMean,
 )
 from stheno.model import (
     Measure,
@@ -140,8 +139,8 @@ def test_naming():
 )
 def test_conditioning(generate_noise_tuple):
     m = Measure()
-    p1 = GP(EQ(), measure=m)
-    p2 = GP(Exp(), measure=m)
+    p1 = GP(1, EQ(), measure=m)
+    p2 = GP(2, Exp(), measure=m)
     p_sum = p1 + p2
 
     # Sample some data to condition on.
@@ -188,7 +187,7 @@ def test_conditioning(generate_noise_tuple):
 
 def test_conditioning_consistency():
     m = Measure()
-    p = GP(EQ(), measure=m)
+    p = GP(1, EQ(), measure=m)
     e = GP(0.1 * Delta(), measure=m)
     e2 = GP(e.kernel, measure=m)
 
@@ -203,17 +202,21 @@ def test_conditioning_consistency():
         assert_equal_normals(post1((p + e)(x)), post2((p + e)(x)))
 
 
-def test_conditioning_prior():
-    p = GP(EQ())
-    x = B.zeros(0, 1)
-    y = B.zeros(0, 1)
-    post = p.measure | (p(x), y)
-    assert post(p).mean is p.mean
-    assert post(p).kernel is p.kernel
+@pytest.mark.parametrize("shape", [(0,), (0, 1), (4, 0, 1)])
+def test_conditioning_empty_observations(shape):
+    p = GP(1, EQ())
+
+    x = B.randn(*shape)
+    y = p(x).sample()
+
+    # Conditioning should just return the prior exactly.
+    p_post = p | (p(x), y)
+    assert p_post.mean is p.mean
+    assert p_post.kernel is p.kernel
 
 
 def test_conditioning_shorthand():
-    p = GP(EQ())
+    p = GP(1, EQ())
 
     # Test conditioning once.
     x = B.linspace(0, 5, 10)
@@ -233,7 +236,7 @@ def test_conditioning_shorthand():
 
 
 def test_conditioning_missing_data():
-    p = GP(EQ())
+    p = GP(1, EQ())
     x = B.linspace(0, 5, 10)
     y = p(x).sample()
     y[:3] = B.nan
@@ -243,7 +246,7 @@ def test_conditioning_missing_data():
 
 
 def test_conditioning_shape_check():
-    f = GP(EQ())
+    f = GP(1, EQ())
     x = B.randn(2)
     f | (f(x), B.randn(2, 1))
     with pytest.raises(ValueError):
@@ -261,8 +264,8 @@ def test_conditioning_shape_check():
 @pytest.mark.parametrize("PseudoObs", [PseudoObs, PseudoObsFITC, PseudoObsDTC])
 def test_pseudoobs_and_elbo(generate_noise_tuple, PseudoObs):
     m = Measure()
-    p1 = GP(EQ(), measure=m)
-    p2 = GP(Exp(), measure=m)
+    p1 = GP(1, EQ(), measure=m)
+    p2 = GP(2, Exp(), measure=m)
     p_sum = p1 + p2
 
     # Sample some data to condition on.
@@ -360,7 +363,7 @@ def test_pseudoobs_kernel_call_count():
     x_new = B.randn(1)
 
     # Perform a pseudo-point approximation
-    p = GP(TrackingEQ())
+    p = GP(1, TrackingEQ())
     p_post = p | PseudoObs(p(x_ind), (p(x_obs, 0.1), y_obs))
     mean, var = p_post(x_new).marginals()
 
@@ -379,8 +382,8 @@ def test_backward_compatibility():
 @pytest.mark.parametrize("PseudoObs", [PseudoObs, PseudoObsFITC, PseudoObsDTC])
 def test_logpdf(PseudoObs):
     m = Measure()
-    p1 = GP(EQ(), measure=m)
-    p2 = GP(Exp(), measure=m)
+    p1 = GP(1, EQ(), measure=m)
+    p2 = GP(2, Exp(), measure=m)
     p3 = p1 + p2
 
     x1 = B.linspace(0, 2, 5)
@@ -410,8 +413,8 @@ def test_logpdf(PseudoObs):
 
 def test_manual_new_gp():
     m = Measure()
-    p1 = GP(EQ(), measure=m)
-    p2 = GP(EQ(), measure=m)
+    p1 = GP(1, EQ(), measure=m)
+    p2 = GP(2, EQ(), measure=m)
     p_sum = p1 + p2
 
     p1_equivalent = m.add_gp(
@@ -427,72 +430,69 @@ def test_manual_new_gp():
 
     x = B.linspace(0, 10, 5)
     s1, s2 = m.sample(p1(x), p1_equivalent(x))
-    approx(s1, s2, rtol=1e-5)
+    approx(s1, s2, atol=1e-4)
 
 
 def test_stretching():
     # Test construction:
-    p = GP(TensorProductMean(lambda x: x**2), EQ())
-    assert str(p.stretch(1)) == "GP(<lambda> > 1, EQ() > 1)"
+    p = GP(lambda x: x**2, Linear())
+    assert str(p.stretch(1)) == "GP(<lambda> > 1, Linear() > 1)"
 
     # Test case:
-    p = GP(EQ())
     p_stretched = p.stretch(5)
 
     x = B.linspace(0, 5, 10)
     y = p_stretched(x).sample()
 
-    post = p.measure | (p_stretched(x), y)
+    post = p.measure | (p_stretched(x, B.epsilon), y)
     assert_equal_normals(post(p(x / 5)), post(p_stretched(x)))
     assert_equal_normals(post(p(x)), post(p_stretched(x * 5)))
 
 
 def test_shifting():
     # Test construction:
-    p = GP(TensorProductMean(lambda x: x**2), Linear())
+    p = GP(lambda x: x**2, Linear())
     assert str(p.shift(1)) == "GP(<lambda> shift 1, Linear() shift 1)"
 
     # Test case:
-    p = GP(EQ())
     p_shifted = p.shift(5)
 
     x = B.linspace(0, 5, 10)
     y = p_shifted(x).sample()
 
-    post = p.measure | (p_shifted(x), y)
+    post = p.measure | (p_shifted(x, B.epsilon), y)
     assert_equal_normals(post(p(x - 5)), post(p_shifted(x)))
     assert_equal_normals(post(p(x)), post(p_shifted(x + 5)))
 
 
 def test_input_transform():
     # Test construction:
-    p = GP(TensorProductMean(lambda x: x**2), EQ())
+    p = GP(lambda x: x**2, Linear())
     assert (
         str(p.transform(lambda x: x))
-        == "GP(<lambda> transform <lambda>, EQ() transform <lambda>)"
+        == "GP(<lambda> transform <lambda>, Linear() transform <lambda>)"
     )
 
     # Test case:
-    p = GP(EQ())
     p_transformed = p.transform(lambda x: B.sqrt(x))
 
     x = B.linspace(0, 5, 10)
     y = p_transformed(x).sample()
 
-    post = p.measure | (p_transformed(x), y)
+    post = p.measure | (p_transformed(x, B.epsilon), y)
     assert_equal_normals(post(p(B.sqrt(x))), post(p_transformed(x)))
     assert_equal_normals(post(p(x)), post(p_transformed(x * x)))
 
 
 def test_selection():
     # Test construction:
-    p = GP(TensorProductMean(lambda x: x**2), EQ())
+    p = GP(lambda x: x**2, EQ())
     assert str(p.select(1)) == "GP(<lambda> : [1], EQ() : [1])"
     assert str(p.select(1, 2)) == "GP(<lambda> : [1, 2], EQ() : [1, 2])"
 
     # Test case:
-    p = GP(EQ())  # 1D
-    p2 = p.select(0)  # 2D
+    # `p` is 1D.
+    p2 = p.select(0)  # `p2` is 2D.
 
     x = B.linspace(0, 5, 10)
     x21 = B.stack(x, B.randn(10), axis=1)
@@ -516,11 +516,10 @@ def test_selection():
 
 def test_derivative():
     # Test construction:
-    p = GP(TensorProductMean(lambda x: x**2), EQ())
+    p = GP(lambda x: x**2, EQ())
     assert str(p.diff(1)) == "GP(d(1) <lambda>, d(1) EQ())"
 
     # Test case:
-    p = GP(EQ())
     dp = p.diff()
 
     x = B.linspace(tf.float64, 0, 1, 100)
@@ -570,7 +569,7 @@ def test_multi_sample():
 
 def test_sample_correct_measure():
     m = Measure()
-    p1 = GP(EQ(), measure=m)
+    p1 = GP(1, EQ(), measure=m)
 
     post = m | (p1(0), 1)
 
