@@ -5,7 +5,9 @@ from lab import B
 from matrix import AbstractMatrix
 from plum import dispatch, Union
 
-__all__ = ["benchmark", "to_np", "approx"]
+from stheno import Normal
+
+__all__ = ["benchmark", "approx"]
 
 
 def benchmark(f, args, n=1000, get_output=False):
@@ -17,6 +19,10 @@ def benchmark(f, args, n=1000, get_output=False):
         args (tuple): Argument to call `f` with.
         n (int): Repetitions.
         get_output (bool): Also return final output of function.
+
+    Returns:
+        float: Time in seconds.
+        object, optional: Output of function.
     """
     start = time()
     for i in range(n):
@@ -25,31 +31,6 @@ def benchmark(f, args, n=1000, get_output=False):
     return (dur, out) if get_output else out
 
 
-@dispatch
-def to_np(a: B.Numeric):
-    return a
-
-
-@dispatch
-def to_np(a: tuple):
-    return tuple(to_np(x) for x in a)
-
-
-@dispatch
-def to_np(a: AbstractMatrix):
-    return B.dense(a)
-
-
-@dispatch
-def to_np(a: list):
-    return np.array(a)
-
-
-@dispatch
-def to_np(a: Union[B.TFNumeric, B.TorchNumeric]):
-    return a.numpy()
-
-
 @dispatch
 def approx(
     a: Union[B.Numeric, AbstractMatrix, list],
@@ -58,7 +39,15 @@ def approx(
     atol=1e-8,
     rtol=1e-8,
 ):
-    np.testing.assert_allclose(to_np(a), to_np(b), atol=atol, rtol=rtol, err_msg=desc)
+    np.testing.assert_allclose(
+        B.to_numpy(a), B.to_numpy(b), atol=atol, rtol=rtol, err_msg=desc
+    )
+
+
+@dispatch
+def approx(a: Normal, b: Normal, desc=None, atol=1e-8, rtol=1e-8):
+    approx(a.mean, b.mean, desc=desc, atol=atol, rtol=rtol)
+    approx(a.var, b.var, desc=desc, atol=atol, rtol=rtol)
 
 
 @dispatch
